@@ -1,5 +1,4 @@
 """Run third-party tool (e.g. :code:`mypy`) against notebook or directory."""
-
 import os
 import re
 import shutil
@@ -39,13 +38,17 @@ EXCLUDES = (
     r")/"
 )
 
-
 REPLACE_FUNCTION = {
     True: replace_source.diff,
     False: replace_source.mutate,
 }
 
 
+def _hash_notebook(string: str) -> int:
+    """Hash notebook name into 8-digits."""
+    return abs(hash(string)) % (10 ** 8)
+
+
 class UnsupportedPackageVersionError(Exception):
     """Raise if installed module is older than minimum required version."""
 
@@ -163,9 +166,9 @@ def _temp_python_file_for_notebook(
         raise FileNotFoundError(
             f"{BOLD}No such file or directory: {str(notebook)}{RESET}"
         )
-    relative_notebook_path = (
-        notebook.resolve().relative_to(project_root).with_suffix(".py")
-    )
+    new_stem = f"{notebook.stem}_{_hash_notebook(notebook.stem)}"
+    new_parent = notebook.resolve().relative_to(project_root).parent
+    relative_notebook_path = (new_parent / new_stem).with_suffix(".py")
     temp_python_file = Path(tmpdir) / relative_notebook_path
     temp_python_file.parent.mkdir(parents=True, exist_ok=True)
     return temp_python_file
@@ -225,6 +228,9 @@ def _replace_temp_python_file_references_in_out_err(
     out = out.replace(f"{tmpdirname}{os.sep}", "")
     err = err.replace(f"{tmpdirname}{os.sep}", "")
 
+    out = out.replace(temp_python_file.stem, notebook.stem)
+    err = err.replace(temp_python_file.stem, notebook.stem)
+
     return out, err
 
 
@@ -553,7 +559,7 @@ def _run_on_one_root_dir(
                 nb_info_mapping[notebook] = save_source.main(
                     notebook,
                     temp_python_file,
-                    configs.nbqa_ignore_cells,
+                    configs.nbqa_process_cells,
                     cli_args.command,
                 )
             except Exception as exc:
@@ -621,15 +627,15 @@ def _run_on_one_root_dir(
                         )
                     ) from exc
 
+        sys.stdout.write(out)
+        sys.stderr.write(err)
+
         if configs.nbqa_diff:
             if mutated:
                 sys.stdout.write(
                     "To apply these changes use `--nbqa-mutate` instead of `--nbqa-diff`\n"
                 )
-            return 0
-
-        sys.stdout.write(out)
-        sys.stderr.write(err)
+            return output_code
 
     return output_code
 
