@@ -2,7 +2,7 @@
 
 from configparser import ConfigParser
 from pathlib import Path
-from typing import Callable, List, Optional, Tuple
+from typing import Callable, Optional, Sequence, Tuple
 
 from nbqa.cmdline import CLIArgs
 from nbqa.config.config import CONFIG_SECTIONS, Configs
@@ -31,12 +31,8 @@ def _parse_nbqa_ini_config(command: str, file_path: Path) -> Optional[Configs]:
     config: Configs = Configs()
     section: str = command
 
-    if config_parser.has_section(section):
-        for option in config_parser.options(section):
-            if option in CONFIG_SECTIONS:
-                config.set_config(
-                    option, config_parser.get(section, option, fallback=None)
-                )
+    for option in config_parser.options(section):
+        config.set_config(option, config_parser.get(section, option, fallback=None))
 
     return config
 
@@ -89,7 +85,7 @@ _ConfigHandler = Callable[..., Optional[Configs]]
 
 CONFIG_PREFIX: str = "nbqa."
 
-_CONFIG_FILE_HANDLERS: List[Tuple[str, Optional[_ConfigHandler]]] = [
+_CONFIG_FILE_HANDLERS: Sequence[Tuple[str, Optional[_ConfigHandler]]] = [
     ("pyproject.toml", parse_from_pyproject_toml),
     ("setup.cfg", _parse_setupcfg_or_toxini_config),
     ("tox.ini", _parse_setupcfg_or_toxini_config),
